@@ -19,17 +19,18 @@
 
 
 from dataclasses import dataclass
-from typing import Any, Dict, Optional
+from typing import Optional
+
+from .model import FetcherMetadata
+
+app_args: Optional["AppArgs"] = None
 
 
 @dataclass
 class AppArgs:
     """Script arguments common to all commands."""
 
-    fetchers_metadata: Dict[str, Any]
+    fetcher_metadata: FetcherMetadata
 
     debug: bool = False
     verbose: bool = False
-
-
-app_args: Optional[AppArgs] = None
